@@ -1,5 +1,6 @@
 from typing import List
 
+import torch
 from numpy import ndarray
 
 from aipose.frame import FrameManagerBase
@@ -10,6 +11,9 @@ class FrameYoloV7(FrameManagerBase):
     def __init__(self):
         self.model = YoloV7Pose()
 
+    def before_read_frame(self):
+        torch.cuda.empty_cache()
+
     def on_frame(self, frame: ndarray) -> ndarray:
         prediction, image_tensor = self.model(frame)
         processed_frame = self.on_predict(frame, prediction, image_tensor)
